==> apimodule-1.0.5.tar.gz: lib/msimpersaa/response/jabatan_response.dart <==
class JabatanResponse {
  bool con;
  String msg;
  List<JabatanResults> results;

  JabatanResponse({this.con, this.msg, this.results});

  JabatanResponse.fromJson(Map<String, dynamic> json) {
    con = json['con'];
    msg = json['msg'];
    if (json['results'] != null) {
      results = <JabatanResults>[];
      json['results'].forEach((v) {
        results.add(JabatanResults.fromJson(v));
      });
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['con'] = this.con;
    data['msg'] = this.msg;
    if (this.results != null) {
      data['results'] = this.results.map((v) => v.toJson()).toList();
    }
    return data;
  }
}

class JabatanResults {
  String skPelantikanNomor;
  String skPelantikanTanggal;
  String skPernyataanTanggal;
  String pejabatPenetap;
  String tmtJabatan;
  String jenisJabatan;
  String namaJabatan;
  String namaEselon;
  String golRuang;
  String documen;
  String pathFile;

  JabatanResults(
      {this.skPelantikanNomor,
      this.skPelantikanTanggal,
      this.skPernyataanTanggal,
      this.pejabatPenetap,
      this.tmtJabatan,
      this.jenisJabatan,
      this.namaJabatan,
      this.namaEselon,
      this.golRuang,
      this.documen,
      this.pathFile});

  JabatanResults.fromJson(Map<String, dynamic> json) {
    skPelantikanNomor = json['sk_pelantikan_nomor'];
    skPelantikanTanggal = json['sk_pelantikan_tanggal'];
    skPernyataanTanggal = json['sk_pernyataan_tanggal'];
    pejabatPenetap = json['pejabat_penetap'];
    tmtJabatan = json['tmt_jabatan'];
    jenisJabatan = json['jenis_jabatan'];
    namaJabatan = json['nama_jabatan'];
    namaEselon = json['nama_eselon'];
    golRuang = json['gol_ruang'];
    documen = json['dokumen'];
    pathFile = json['path_file'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['sk_pelantikan_nomor'] = this.skPelantikanNomor;
    data['sk_pelantikan_tanggal'] = this.skPelantikanTanggal;
    data['sk_pernyataan_tanggal'] = this.skPernyataanTanggal;
    data['pejabat_penetap'] = this.pejabatPenetap;
    data['tmt_jabatan'] = this.tmtJabatan;
    data['jenis_jabatan'] = this.jenisJabatan;
    data['nama_jabatan'] = this.namaJabatan;
    data['nama_eselon'] = this.namaEselon;
    data['gol_ruang'] = this.golRuang;
    data['dokumen'] = this.documen;
    data['path_file'] = this.pathFile;
    return data;
  }
}

==> apimodule-1.0.6.tar.gz: lib/msimpersaa/response/jabatan_response.dart <==
class JabatanResponse {
  bool con;
  String msg;
  List<JabatanResults> results;

  JabatanResponse({this.con, this.msg, this.results});

  JabatanResponse.fromJson(Map<String, dynamic> json) {
    con = json['con'];
    msg = json['msg'];
    if (json['results'] != null) {
      results = <JabatanResults>[];
      json['results'].forEach((v) {
        results.add(JabatanResults.fromJson(v));
      });
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['con'] = this.con;
    data['msg'] = this.msg;
    if (this.results != null) {
      data['results'] = this.results.map((v) => v.toJson()).toList();
    }
    return data;
  }
}

class JabatanResults {
  String skPelantikanNomor;
  String skPelantikanTanggal;
  String skPernyataanTanggal;
  String pejabatPenetap;
  String tmtJabatan;
  String jenisJabatan;
  String namaJabatan;
  String namaEselon;
  String golRuang;
  String document;
  String pathFile;

  JabatanResults(
      {this.skPelantikanNomor,
      this.skPelantikanTanggal,
      this.skPernyataanTanggal,
      this.pejabatPenetap,
      this.tmtJabatan,
      this.jenisJabatan,
      this.namaJabatan,
      this.namaEselon,
      this.golRuang,
      this.document,
      this.pathFile});

  JabatanResults.fromJson(Map<String, dynamic> json) {
    skPelantikanNomor = json['sk_pelantikan_nomor'];
    skPelantikanTanggal = json['sk_pelantikan_tanggal'];
    skPernyataanTanggal = json['sk_pernyataan_tanggal'];
    pejabatPenetap = json['pejabat_penetap'];
    tmtJabatan = json['tmt_jabatan'];
    jenisJabatan = json['jenis_jabatan'];
    namaJabatan = json['nama_jabatan'];
    namaEselon = json['nama_eselon'];
    golRuang = json['gol_ruang'];
    document = json['dokumen'];
    pathFile = json['path_file'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['sk_pelantikan_nomor'] = this.skPelantikanNomor;
    data['sk_pelantikan_tanggal'] = this.skPelantikanTanggal;
    data['sk_pernyataan_tanggal'] = this.skPernyataanTanggal;
    data['pejabat_penetap'] = this.pejabatPenetap;
    data['tmt_jabatan'] = this.tmtJabatan;
    data['jenis_jabatan'] = this.jenisJabatan;
    data['nama_jabatan'] = this.namaJabatan;
    data['nama_eselon'] = this.namaEselon;
    data['gol_ruang'] = this.golRuang;
    data['dokumen'] = this.document;
    data['path_file'] = this.pathFile;
    return data;
  }
}
